@@ -33,7 +33,7 @@ read_done = False
 def _load_protocol():
     global port_dict
     global read_done
-    
+
     if read_done:
         return port_dict
 
@@ -43,9 +43,9 @@ def _load_protocol():
     try: fd = open("/etc/protocols", "r")
     except IOError:
         return port_dict
-	
+
     for line in fd.readlines():
-	
+
         ret = sreg.match(line)
         if not ret:
             continue
@@ -64,7 +64,7 @@ def protocol_number_to_name(num):
 
      return None
 
-def escape_attribute(value):   
+def escape_attribute(value):
     # Escape '\' since it's a valid js escape.
     return value.replace("\\", "\\\\").replace("\"", "\\\"").replace("/", "\\/")
 
@@ -95,7 +95,12 @@ def urlencode(parameters, doseq=False):
 
 def create_link(action_name, parameters=None):
     link = "?view=%s" % action_name
+
     if parameters:
+        for k in parameters.keys():
+            if isinstance(parameters[k], unicode):
+                parameters[k] = parameters[k].encode("utf8")
+
         link += "&%s" % urllib.urlencode(parameters, doseq=True)
 
     return link
@@ -118,7 +123,9 @@ def boolean_property(name, parameter, value=False):
 
 
 def escape_html_string(s):
-    s = str(s)
+    if not isinstance(s, str) and not isinstance(s, unicode):
+        s = toUnicode(s)
+
     s = s.replace("&", "&amp;")
     s = s.replace("<", "&lt;")
     s = s.replace(">", "&gt;")
@@ -139,7 +146,7 @@ def hexdump(content):
 
         content += "   " * (16 - len(chunk))
         content += "    "
-        
+
         for b in chunk:
             if b >= 32 and b < 127:
                 content += chr(b)
@@ -150,3 +157,67 @@ def hexdump(content):
         i += 16
 
     return content
+
+
+def isUTF8(text):
+    try:
+        text = unicode(text, 'UTF-8', 'strict')
+        return True
+    except UnicodeDecodeError:
+        return False
+
+def toUnicode(text):
+    r"""
+    >>> toUnicode('ascii')
+    u'ascii'
+    >>> toUnicode(u'utf\xe9'.encode('UTF-8'))
+    u'utf\xe9'
+    >>> toUnicode(u'unicode')
+    u'unicode'
+    """
+    if isinstance(text, dict):
+        for k in text.keys():
+            text[k] = toUnicode(text[k])
+        return text
+
+    elif isinstance(text, list):
+        return [ toUnicode(i) for i in text ]
+
+    if isinstance(text, unicode):
+        return text
+
+    if not isinstance(text, str):
+        text = str(text)
+
+    try:
+        return unicode(text, "utf8")
+    except UnicodeError:
+        pass
+
+    return unicode(text, "ISO-8859-1")
+
+
+
+class OrderedDict(dict):
+    def __init__(self, *args, **kwargs):
+        dict.__init__(self, *args, **kwargs)
+        self._order = dict.keys(self)
+
+    def __setitem__(self, key, value):
+        dict.__setitem__(self, key, value)
+        if key in self._order:
+            self._order.remove(key)
+        self._order.append(key)
+
+    def __delitem__(self, key):
+        dict.__delitem__(self, key)
+        self._order.remove(key)
+
+    def keys(self):
+        return self._order[:]
+
+    def items(self):
+        return [(key,self[key]) for key in self._order]
+
+    def values(self):
+        return [ self[key] for key in self._order]
