@@ -22,6 +22,7 @@ import re
 import time
 import struct
 import socket
+import urllib
 
 from prewikka import view, User, utils, resolve
 
@@ -446,10 +447,10 @@ class MessageSummary(Table):
 
         if node["name"]:
             self.newTableEntry(_("Node name"), node["name"])
-	
-        elif node_name:
+
+        elif node_name.resolveSucceed():
             self.newTableEntry(_("Node name (resolved)"), node_name)
-            
+
         self.newTableEntry(_("Node address"), addr_list)
 
     def buildAnalyzer(self, analyzer):
@@ -541,6 +542,8 @@ class MessageSummary(Table):
                         value = utils.hexdump(value)
                 else:
                     value = ad.get("data")
+                    if isinstance(value, str):
+                        value = utils.toUnicode(value)
 
             for field in ignore:
                 if meaning != None and meaning == field[0]:
@@ -655,17 +658,22 @@ class AlertSummary(TcpIpOptions, MessageSummary, view.View):
         for analyzerid in calist.keys():
 
             content = ""
+            missing = 0
             for ident in calist[analyzerid]:
                 criteria = "alert.analyzer.analyzerid = '%s' && alert.messageid = '%s'" % (analyzerid, ident)
 
                 results = self.env.idmef_db.getAlertIdents(criteria)
                 if len(results) == 0:
-                    content += "<li>" + _("Invalid 'analyzerid:messageid' pair, '%(analyzerid):%(messageid)'") % { "analyzerid": analyzerid, "messageid": messageid } + "</li>"
+                    missing += 1
+                    #content += "<li>" + _("Invalid 'analyzerid:messageid' pair, '%(analyzerid):%(messageid)'") % { "analyzerid": analyzerid, "messageid": ident } + "</li>"
                 else:
                     alert = self.env.idmef_db.getAlert(results[0], htmlsafe=True)
                     link = utils.create_link("alert_summary", { "origin": self.parameters["origin"], "ident": results[0] })
                     content += "<li><a href=\"%s\">%s</a></li>" % (link, alert["classification.text"])
 
+            if missing > 0:
+                content += "<li>" + (_("%d linked alerts missing (probably deleted)") % missing) + "</li>"
+
             self.newTableCol(idx, "<ul style='padding: 0px; margin: 0px 0px 0px 10px;'>%s</ul>" % content)
             self.buildAnalyzer(alert["analyzer(-1)"])
             self.newTableRow()
@@ -727,11 +735,11 @@ class AlertSummary(TcpIpOptions, MessageSummary, view.View):
         for reference in alert["classification.reference"]:
             self.newTableCol(index, reference["origin"])
             if reference["origin"] in ("user-specific", "vendor-specific"):
-                urlstr="&url=%s" % reference["url"]
+                urlstr="&url=" + urllib.quote(reference["url"], safe="")
             else:
                 urlstr=""
 
-            self.newTableCol(index, self.getUrlLink(reference["name"], "http://www.prelude-ids.com/reference_details.php?origin=%s&name=%s%s" % (reference["origin"], reference["name"], urlstr)))
+            self.newTableCol(index, self.getUrlLink(reference["name"], "http://www.prelude-ids.com/reference_details.php?origin=%s&name=%s%s" % (urllib.quote(reference["origin"]), urllib.quote(reference["name"]), urlstr)))
             self.newTableCol(index, reference["meaning"])
             index += 1
 
@@ -905,7 +913,7 @@ class AlertSummary(TcpIpOptions, MessageSummary, view.View):
             for port in portlist.replace(" ", "").split(","):
                 if len(out) > 0:
                     out += ", "
-                    
+
                 if port.find("-") != -1:
                     left, right = port.split("-")
                     out += self.getUrlLink(left, "https://www.prelude-ids.com/port_details.php?port=%s" % left)
@@ -913,12 +921,12 @@ class AlertSummary(TcpIpOptions, MessageSummary, view.View):
                     out += self.getUrlLink(right, "https://www.prelude-ids.com/port_details.php?port=%s" % right)
                 else:
                     out += self.getUrlLink(port, "https://www.prelude-ids.com/port_details.php?port=%s" % port)
-                    
+
             self.newTableEntry(_("PortList"), out)
 
         if service["ip_version"]:
             self.newTableEntry(_("ip_version"), service["ip_version"])
-            
+
         ipn = service["iana_protocol_number"]
         if ipn and utils.protocol_number_to_name(ipn) != None:
             self.newTableEntry(_("Protocol"), utils.protocol_number_to_name(ipn))
@@ -998,13 +1006,13 @@ class AlertSummary(TcpIpOptions, MessageSummary, view.View):
         self.dataset["sections"] = [ ]
 
         self.beginSection(self.getSectionName(alert))
-        
+
         self.buildTime(alert)
 
         self.beginTable()
         self.newTableEntry(_("MessageID"), alert["messageid"])
         self.endTable()
-        
+
         self.beginTable()
         self.buildClassification(alert)
         self.buildImpact(alert)
@@ -1068,8 +1076,7 @@ class AlertSummary(TcpIpOptions, MessageSummary, view.View):
                 val["payload"] = "<span class='fixed'>%s</span>" % payload
                 data.render_table(self, _("Payload"), val)
 
-                payload = utils.escape_html_string(ignored_value["payload"]).replace(" ", "&nbsp;")
-                val["payload"] = "<div style='overflow: auto;'>%s</div>" % utils.escape_html_string(ignored_value["payload"]).replace("\n", "<br/>")
+                val["payload"] = "<div style='overflow: auto;'>%s</div>" % utils.escape_html_string(utils.toUnicode(ignored_value["payload"])).replace("\n", "<br/>")
                 data.render_table(self, _("ASCII Payload"), val)
 
             self.endTable()
